==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/lt_LT.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Žiūryklė",
    "Simple file viewer with slideshow for media" : "Paprasta failų žiūryklė su medijos skaidrių rodymu",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Rodykite savo paskiausių atostogų nuotraukas ir vaizdo įrašus, visai kaip filmuose, rodykite ištrauką iš savo naujausios novelės tiesiai iš savo Nextcloud, pasirinkite geriausią savo kolekcijos GIF, naudodami tiesioginę savo mėgstamų failų peržiūrą ir žymiai daugiau!",
    "Your browser does not support audio." : "Jūsų naršyklė nepalaiko garso.",
    "Error loading {name}" : "Klaida įkeliant {name}",
    "Image saved" : "Paveikslas įrašytas",
    "Error saving image" : "Klaida įrašant paveikslą",
    "Unsaved changes" : "Neįrašyti pakeitimai",
    "Drop changes" : "Atmesti pakeitimus",
    "Your browser does not support videos." : "Jūsų naršyklė nepalaiko vaizdo įrašų. ",
    "This file no longer exists" : "Šio failo daugiau nebėra",
    "There is no plugin available to display this file type" : "Nėra prieinamo įskiepio, skirto atvaizduoti šį failo tipą",
    "Edit" : "Taisyti",
    "Full screen" : "Visas ekranas",
    "Open sidebar" : "Atverti šoninę juostą",
    "Download" : "Atsisiųsti",
    "Delete" : "Ištrinti",
    "View" : "Rodyti",
    "Name" : "Pavadinimas",
    "Save" : "Įrašyti",
    "Save as" : "Įrašyti kaip",
    "Back" : "Atgal",
    "Loading …" : "Įkeliama…",
    "Reset" : "Atstatyti",
    "All changes will be lost." : "Visi pakeitimai bus prarasti.",
    "Are you sure you want to continue?" : "Ar tikrai norite tęsti?",
    "Cancel" : "Atsisakyti",
    "Apply" : "Taikyti",
    "Warning" : "Įspėjimas",
    "Confirm" : "Patvirtinti",
    "Discard changes" : "Atmesti pakeitimus",
    "Undo" : "Atšaukti",
    "Redo" : "Grąžinti",
    "Zoom in" : "Didinti",
    "Zoom out" : "Mažinti",
    "Toggle zoom menu" : "Perjungti mastelio meniu",
    "Filters" : "Filtrai",
    "Resize" : "Keisti dydį",
    "Crop" : "Apkirpti",
    "Custom" : "Tinkinti",
    "Landscape" : "Kraštovaizdis",
    "Portrait" : "Portretas",
    "Hue" : "Atspalvis",
    "Value" : "Reikšmė",
    "Image" : "Paveikslas",
    "Importing …" : "Importuojama…",
    "From gallery" : "Iš galerijos",
    "Rotate" : "Pasukti",
    "Text" : "Tekstas",
    "Font family" : "Šriftas",
    "Size" : "Dydis",
    "Add as text" : "Pridėti kaip tekstą",
    "Position" : "Vieta",
    "Name is required." : "Pavadinimas yra būtinas.",
    "Quality" : "Kokybė",
    "Menu" : "Meniu",
    "Width" : "Plotis",
    "Height" : "Aukštis"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/lt_LT.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Žiūryklė",
    "Simple file viewer with slideshow for media" : "Paprasta failų žiūryklė su medijos skaidrių rodymu",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Rodykite savo paskiausių atostogų nuotraukas ir vaizdo įrašus, visai kaip filmuose, rodykite ištrauką iš savo naujausios novelės tiesiai iš savo Nextcloud, pasirinkite geriausią savo kolekcijos GIF, naudodami tiesioginę savo mėgstamų failų peržiūrą ir žymiai daugiau!",
    "Your browser does not support audio." : "Jūsų naršyklė nepalaiko garso.",
    "Error loading {name}" : "Klaida įkeliant {name}",
    "Cancel" : "Atsisakyti",
    "Image saved" : "Paveikslas įrašytas",
    "Error saving image" : "Klaida įrašant paveikslą",
    "Your browser does not support videos." : "Jūsų naršyklė nepalaiko vaizdo įrašų. ",
    "This file no longer exists" : "Šio failo daugiau nebėra",
    "There is no plugin available to display this file type" : "Nėra prieinamo įskiepio, skirto atvaizduoti šį failo tipą",
    "Edit" : "Taisyti",
    "Full screen" : "Visas ekranas",
    "Open sidebar" : "Atverti šoninę juostą",
    "Download" : "Atsisiųsti",
    "Delete" : "Ištrinti",
    "View" : "Rodyti",
    "Name" : "Pavadinimas",
    "Save" : "Įrašyti",
    "Save as" : "Įrašyti kaip",
    "Back" : "Atgal",
    "Loading …" : "Įkeliama…",
    "Reset" : "Atstatyti",
    "All changes will be lost." : "Visi pakeitimai bus prarasti.",
    "Are you sure you want to continue?" : "Ar tikrai norite tęsti?",
    "Apply" : "Taikyti",
    "Warning" : "Įspėjimas",
    "Confirm" : "Patvirtinti",
    "Discard changes" : "Atmesti pakeitimus",
    "Undo" : "Atšaukti",
    "Redo" : "Grąžinti",
    "Zoom in" : "Didinti",
    "Zoom out" : "Mažinti",
    "Toggle zoom menu" : "Perjungti mastelio meniu",
    "Filters" : "Filtrai",
    "Resize" : "Keisti dydį",
    "Crop" : "Apkirpti",
    "Custom" : "Tinkinti",
    "Landscape" : "Kraštovaizdis",
    "Portrait" : "Portretas",
    "Hue" : "Atspalvis",
    "Value" : "Reikšmė",
    "Image" : "Paveikslas",
    "Importing …" : "Importuojama…",
    "Upload image" : "Įkelti paveikslą",
    "From gallery" : "Iš galerijos",
    "Rotate" : "Pasukti",
    "Text" : "Tekstas",
    "Font family" : "Šriftas",
    "Size" : "Dydis",
    "Add as text" : "Pridėti kaip tekstą",
    "Position" : "Vieta",
    "Name is required." : "Pavadinimas yra būtinas.",
    "Quality" : "Kokybė",
    "Menu" : "Meniu",
    "Width" : "Plotis",
    "Height" : "Aukštis"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
